Validation helpers for path and text inputs.
Functions
- reject_
unicode_ controls - Reject control characters that can hide or reorder text.
- validate_
optional_ trimmed - Validate an optional string when present and return
Nonefor absent values. - validate_
path_ safe_ identifier - Validate a required identifier that is safe to use as a path segment.
- validate_
required_ trimmed - Validate a required string that must not contain leading or trailing whitespace.
- validate_
safe_ path - Validate that a path-like input cannot traverse outside its base.